@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Dump;
 
-our $DATE = '2017-01-07'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2017-01-13'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -99,9 +99,6 @@ sub dump_pericmd_script {
         require Perinci::CmdLine::Lite;
         $res->[2] = Perinci::CmdLine::Lite->new(
             %$attrs,
-            # unsupported stuffs
-            read_config => 0,
-            read_env => 0,
         );
         goto RETURN_RES;
     }
@@ -184,7 +181,7 @@ Perinci::CmdLine::Dump - Run a Perinci::CmdLine-based script but only to dump th
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2017-01-07.
+This document describes version 0.08 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2017-01-13.
 
 =for Pod::Coverage ^(dump_perinci_cmdline_script)$
 
